pub enum Ellipsis {
None,
Start,
Middle,
End,
}Expand description
The ellipsis strategy of some text.
Variants
None
No ellipsis.
This is the default.
Start
Ellipsize the start of the last visual line in the text.
Middle
Ellipsize the middle of the last visual line in the text.
End
Ellipsize the end of the last visual line in the text.