Span

Struct Span 

pub struct Span<'a, Link = ()> {
    pub text: Fragment<'a>,
    pub size: Option<Pixels>,
    pub line_height: Option<LineHeight>,
    pub font: Option<Font>,
    pub color: Option<Color>,
    pub link: Option<Link>,
    pub highlight: Option<Highlight>,
    pub padding: Padding,
    pub underline: bool,
    pub strikethrough: bool,
}
A span of text.

Fields

text: Fragment<'a>

The Fragment of text.

size: Option<Pixels>

The size of the Span in Pixels.

line_height: Option<LineHeight>

The LineHeight of the Span.

font: Option<Font>

The Font of the Span.

color: Option<Color>

The Color of the Span.

link: Option<Link>

The link of the Span.

highlight: Option<Highlight>

The Highlight of the Span.

padding: Padding

The Padding of the Span.

Currently, it only affects the bounds of the Highlight.

underline: bool

Whether the Span should be underlined or not.

strikethrough: bool

Whether the Span should be struck through or not.

Implementations

Source

impl<'a, Link> Span<'a, Link>

pub fn new(fragment: impl IntoFragment<'a>) -> Self

Creates a new Span of text with the given text fragment.

pub fn size(self, size: impl Into<Pixels>) -> Self

Sets the size of the Span.

pub fn line_height(self, line_height: impl Into<LineHeight>) -> Self

Sets the LineHeight of the Span.

pub fn font(self, font: impl Into<Font>) -> Self

Sets the font of the Span.

pub fn font_maybe(self, font: Option<impl Into<Font>>) -> Self

Sets the font of the Span, if any.

pub fn color(self, color: impl Into<Color>) -> Self

Sets the Color of the Span.

pub fn color_maybe(self, color: Option<impl Into<Color>>) -> Self

Sets the Color of the Span, if any.

Sets the link of the Span.

Sets the link of the Span, if any.

pub fn background(self, background: impl Into<Background>) -> Self

Sets the Background of the Span.

pub fn background_maybe(self, background: Option<impl Into<Background>>) -> Self

Sets the Background of the Span, if any.

pub fn border(self, border: impl Into<Border>) -> Self

Sets the Border of the Span.

pub fn border_maybe(self, border: Option<impl Into<Border>>) -> Self

Sets the Border of the Span, if any.

pub fn padding(self, padding: impl Into<Padding>) -> Self

Sets the Padding of the Span.

It only affects the background and border of the Span, currently.

pub fn underline(self, underline: bool) -> Self

Sets whether the Span should be underlined or not.

pub fn strikethrough(self, strikethrough: bool) -> Self

Sets whether the Span should be struck through or not.

pub fn to_static(self) -> Span<'static, Link>

Turns the Span into a static one.